@@ -4,18 +4,18 @@ import ast
 from typing import TYPE_CHECKING, Any, List, Optional
 
 from robot.parsing.model.blocks import If, Keyword, TestCase
-from robotcode.core.lsp.types import FoldingRange
-from robotcode.core.utils.logging import LoggingDescriptor
 
-from ...common.decorators import language_id
-from ...common.text_document import TextDocument
-from ..utils.async_ast import Visitor
+from robotcode.core.concurrent import check_current_task_canceled
+from robotcode.core.language import language_id
+from robotcode.core.lsp.types import FoldingRange
+from robotcode.core.text_document import TextDocument
+from robotcode.core.utils.logging import LoggingDescriptor
+from robotcode.robot.utils.visitor import Visitor
+
 from .protocol_part import RobotLanguageServerProtocolPart
 
 if TYPE_CHECKING:
-    from robotcode.language_server.robotframework.protocol import (
-        RobotLanguageServerProtocol,
-    )
+    from ..protocol import RobotLanguageServerProtocol
 
 
 class _Visitor(Visitor):
@@ -37,6 +37,7 @@ class _Visitor(Visitor):
         self.current_if: List[ast.AST] = []
 
     def visit(self, node: ast.AST) -> None:
+        check_current_task_canceled()
         super().visit(node)
 
     @classmethod
@@ -100,7 +101,11 @@ class _Visitor(Visitor):
         if node.orelse is not None and node.body[-1]:
             self.__append(node, kind="if", end_node=node.body[-1])
         elif node.orelse is None and node.type == "ELSE":
-            self.__append(node, kind="if", end_node=self.current_if[-1] if self.current_if else None)
+            self.__append(
+                node,
+                kind="if",
+                end_node=self.current_if[-1] if self.current_if else None,
+            )
         else:
             self.__append(node, kind="if")
 
@@ -123,5 +128,5 @@ class RobotFoldingRangeProtocolPart(RobotLanguageServerProtocolPart):
 
     @language_id("robotframework")
     @_logger.call
-    async def collect(self, sender: Any, document: TextDocument) -> Optional[List[FoldingRange]]:
-        return _Visitor.find_from(await self.parent.documents_cache.get_model(document, False), self)
+    def collect(self, sender: Any, document: TextDocument) -> Optional[List[FoldingRange]]:
+        return _Visitor.find_from(self.parent.documents_cache.get_model(document, False), self)
